import Vue from "vue";
import Router from "vue-router";

Vue.use(Router);

/* Layout */
import Layout from "@/layout";

/* Router Modules */

/**
 * Note: sub-menu only appear when route children.length >= 1
 * Detail see: https://panjiachen.github.io/vue-element-admin-site/guide/essentials/router-and-nav.html
 *
 * hidden: true                   if set true, item will not show in the sidebar(default is false)
 * alwaysShow: true               if set true, will always show the root menu
 *                                if not set alwaysShow, when item has more than one children route,
 *                                it will becomes nested mode, otherwise not show the root menu
 * redirect: noRedirect           if set noRedirect will no redirect in the breadcrumb
 * name:'router-name'             the name is used by <keep-alive> (must set!!!)
 * meta : {
    roles: ['admin','editor']    control the page roles (you can set multiple roles)
    title: 'title'               the name show in sidebar and breadcrumb (recommend set)
    icon: 'svg-name'/'el-icon-x' the icon show in the sidebar
    noCache: true                if set true, the page will no be cached(default is false)
    affix: true                  if set true, the tag will affix in the tags-view
    breadcrumb: false            if set false, the item will hidden in breadcrumb(default is true)
    activeMenu: '/example/list'  if set path, the sidebar will highlight the path you set
  }
 */

/**
 * constantRoutes
 * a base page that does not have permission requirements
 * all roles can be accessed
 */
export const constantRoutes = [
  {
    path: "/",
    component: Layout,
    redirect: "/consumer/list",
  },
  // {
  //   path: "/staff",
  //   component: Layout,
  //   name: "Staff",
  //   meta: {
  //     title: "员工管理",
  //     // icon: 'user'
  //   },
  //   children: [
  //     {
  //       path: "list",
  //       component: () => import("@/views/staff/list.vue"),
  //       name: "StaffList",
  //       meta: { title: "员工管理" },
  //     },
  //     {
  //       path: "detail",
  //       component: () => import("@/views/staff/detail.vue"),
  //       name: "StaffDetail",
  //       meta: { title: "员工详情" },
  //       hidden: true,
  //     },
  //     {
  //       path: "create",
  //       component: () => import("@/views/staff/detail.vue"),
  //       name: "StaffCreate",
  //       meta: { title: "创建员工" },
  //       hidden: true,
  //     },
  //     {
  //       path: "update",
  //       component: () => import("@/views/staff/detail.vue"),
  //       name: "StaffUpdate",
  //       meta: { title: "员工编辑" },
  //       hidden: true,
  //     },
  //   ],
  // },
  {
    path: "/redirect",
    component: Layout,
    hidden: true,
    children: [
      {
        path: "/redirect/:path(.*)",
        component: () => import("@/views/redirect/index"),
      },
    ],
  },
  {
    path: "/login",
    component: () => import("@/views/login/index"),
    hidden: true,
  },
  {
    path: "/auth-redirect",
    component: () => import("@/views/login/auth-redirect"),
    hidden: true,
  },
  {
    path: "/404",
    component: () => import("@/views/error-page/404"),
    hidden: true,
  },
  {
    path: "/401",
    component: () => import("@/views/error-page/401"),
    hidden: true,
  },
];

/**
 * asyncRoutes
 * the routes that need to be dynamically loaded based on user roles
 */
export const asyncRoutes = [
  {
    path: "/consumer",
    component: Layout,
    name: "Consumer",
    meta: {
      title: "用户管理",
      // icon: 'user',
      // roles: ['root'],
    },
    children: [
      {
        path: "list",
        component: () => import("@/views/consumer/list.vue"),
        name: "ConsumerList",
        meta: { title: "用户管理" },
      },
      // {
      //   path: "create",
      //   component: () => import("@/views/consumer/detail.vue"),
      //   name: "ConsumerCreate",
      //   meta: { title: "创建用户信息" },
      //   hidden: true,
      // },
      // {
      //   path: "update",
      //   component: () => import("@/views/consumer/detail.vue"),
      //   name: "ConsumerDetail",
      //   meta: { title: "修改用户信息" },
      //   hidden: true,
      // },
    ],
  },

  
  {
    path: "/label",
    component: Layout,
    name: "Label",
    meta: {
      title: "标签管理",
    },
    children: [
      {
        path: "list",
        component: () => import("@/views/label/list.vue"),
        name: "LabelList",
        meta: { title: "标签管理" },
      },
      {
        path: "group",
        component: () => import("@/views/label/group.vue"),
        name: "LabeGroupList",
        meta: { title: "标签组管理" },
      },
    ],
  },
  {
    path: "/config",
    component: Layout,
    name: "Config",
    meta: {
      title: "系统管理",
    },
    children: [
      {
        path: "config",
        component: () => import("@/views/config/list.vue"),
        name: "Config",
        meta: { title: "系统管理" },
      },
    ],
  },

  { path: "*", redirect: "/404", hidden: true },
];

const createRouter = () =>
  new Router({
    // mode: 'history', // require service support
    scrollBehavior: () => ({ y: 0 }),
    routes: constantRoutes,
  });

const router = createRouter();

// Detail see: https://github.com/vuejs/vue-router/issues/1234#issuecomment-357941465
export function resetRouter() {
  const newRouter = createRouter();
  router.matcher = newRouter.matcher; // reset router
}

export default router;
