import { asyncRoutes, constantRoutes } from '@/router'

/**
 * Use meta.role to determine if the current user has permission
 * @param roles
 * @param route
 */
function hasPermission(roles, route) {
  if (route.meta && route.meta.roles) {
    return roles.some(role => route.meta.roles.includes(role))
  } else {
    return true
  }
}

/**
 * Filter asynchronous routing tables by recursion
 * @param routes asyncRoutes
 * @param roles
 */
export function filterAsyncRoutes(routes, roles) {
  const res = []

  routes.forEach(route => {
    const tmp = { ...route }
    if (hasPermission(roles, tmp)) {
      if (tmp.children) {
        // tmp.children = filterAsyncRoutes(tmp.children, roles)
        const children = filterAsyncRoutes(tmp.children, roles)
        // 添加子路由是否全部 hidden (是: 隐藏父级路由)
        const notHiddenChildIndex = children.findIndex(item => !item.hidden)
        if (notHiddenChildIndex !== -1) {
          tmp.children = children
        } else {
          tmp.hidden = true
        }
      }
      res.push(tmp)
    }
  })
  console.log(res)

  return res
}

const state = {
  routes: [],
  addRoutes: []
}

const mutations = {
  SET_ROUTES: (state, routes) => {
    state.addRoutes = routes
    state.routes = constantRoutes.concat(routes)
  }
}

const actions = {
  generateRoutes({ commit }, roles) {
    console.log(roles)
    return new Promise(resolve => {
      let accessedRoutes = asyncRoutes
      if (roles.includes('root')) {
        accessedRoutes = asyncRoutes || []
      } else {
        accessedRoutes = filterAsyncRoutes(asyncRoutes, roles)
      }
      //  else {
      //   accessedRoutes = roleRouter[roles[0]]
      // }
      commit('SET_ROUTES', accessedRoutes)
      resolve(accessedRoutes)
    })
  }
}

export default {
  namespaced: true,
  state,
  mutations,
  actions
}
